@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import re
-from typing import Any, Dict, Optional, Union
+from typing import Any
 
 from wikibaseintegrator.entities.baseentity import BaseEntity
 from wikibaseintegrator.models import LanguageValues
@@ -14,7 +14,7 @@ from wikibaseintegrator.models.sitelinks import Sitelinks
 class ItemEntity(BaseEntity):
     ETYPE = 'item'
 
-    def __init__(self, labels: Optional[Labels] = None, descriptions: Optional[Descriptions] = None, aliases: Optional[Aliases] = None, sitelinks: Optional[Sitelinks] = None, **kwargs: Any) -> None:
+    def __init__(self, labels: Labels | None = None, descriptions: Descriptions | None = None, aliases: Aliases | None = None, sitelinks: Sitelinks | None = None, **kwargs: Any) -> None:
         """
 
         :param api:
@@ -34,6 +34,25 @@ class ItemEntity(BaseEntity):
         # Item specific
         self.sitelinks = sitelinks or Sitelinks()
 
+    @BaseEntity.id.setter  # type: ignore
+    def id(self, value: None | str | int):
+        if isinstance(value, str):
+            pattern = re.compile(r'^(?:[a-zA-Z]+:)?Q?([0-9]+)$')
+            matches = pattern.match(value)
+
+            if not matches:
+                raise ValueError(f"Invalid item ID ({value}), format must be 'Q[0-9]+'")
+
+            value = f'Q{matches.group(1)}'
+        elif isinstance(value, int):
+            value = f'Q{value}'
+        elif value is None:
+            pass
+        else:
+            raise ValueError(f"Invalid item ID ({value}), format must be 'Q[0-9]+'")
+
+        BaseEntity.id.fset(self, value)  # type: ignore
+
     @property
     def labels(self) -> Labels:
         return self.__labels
@@ -77,7 +96,7 @@ class ItemEntity(BaseEntity):
     def new(self, **kwargs: Any) -> ItemEntity:
         return ItemEntity(api=self.api, **kwargs)
 
-    def get(self, entity_id: Optional[Union[str, int]] = None, **kwargs: Any) -> ItemEntity:
+    def get(self, entity_id: str | int | None = None, **kwargs: Any) -> ItemEntity:
         """
         Request the MediaWiki API to get data for the entity specified in argument.
 
@@ -107,7 +126,7 @@ class ItemEntity(BaseEntity):
         json_data = super()._get(entity_id=entity_id, **kwargs)
         return ItemEntity(api=self.api).from_json(json_data=json_data['entities'][entity_id])
 
-    def get_json(self) -> Dict[str, Union[str, Dict]]:
+    def get_json(self) -> dict[str, str | dict]:
         """
         To get the dict equivalent of the JSON representation of the Item.
 
@@ -117,10 +136,11 @@ class ItemEntity(BaseEntity):
             'labels': self.labels.get_json(),
             'descriptions': self.descriptions.get_json(),
             'aliases': self.aliases.get_json(),
+            'sitelinks': self.sitelinks.get_json(),
             **super().get_json()
         }
 
-    def from_json(self, json_data: Dict[str, Any]) -> ItemEntity:
+    def from_json(self, json_data: dict[str, Any]) -> ItemEntity:
         super().from_json(json_data=json_data)
 
         self.labels = Labels().from_json(json_data['labels'])
