@@ -1,8 +1,9 @@
 from __future__ import annotations
 
 import copy
+import warnings
 from abc import abstractmethod
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Callable
 
 from wikibaseintegrator.models.basemodel import BaseModel
 from wikibaseintegrator.models.qualifiers import Qualifiers
@@ -13,20 +14,26 @@ from wikibaseintegrator.wbi_enums import ActionIfExists, WikibaseRank, WikibaseS
 
 class Claims(BaseModel):
     def __init__(self) -> None:
-        self.claims: Dict[str, List[Claim]] = {}
+        self.claims: dict[str, list[Claim]] = {}
 
     @property
-    def claims(self) -> Dict[str, List[Claim]]:
+    def claims(self) -> dict[str, list[Claim]]:
         return self.__claims
 
     @claims.setter
-    def claims(self, claims: Dict[str, List[Claim]]):
+    def claims(self, claims: dict[str, list[Claim]]):
         self.__claims = claims
 
-    def get(self, property: str) -> List[Claim]:
-        return self.claims[property]
+    def get(self, property: str | int) -> list[Claim]:
+        if isinstance(property, int):
+            property = 'P' + str(property)
 
-    def remove(self, property: Optional[str] = None) -> None:
+        if property in self.claims:
+            return self.claims[property]
+
+        return []
+
+    def remove(self, property: str | None = None) -> None:
         if property in self.claims:
             for prop in self.claims[property]:
                 if prop.id:
@@ -36,7 +43,7 @@ class Claims(BaseModel):
             if len(self.claims[property]) == 0:
                 del self.claims[property]
 
-    def add(self, claims: Union[Claims, List[Claim], Claim], action_if_exists: ActionIfExists = ActionIfExists.REPLACE_ALL) -> Claims:
+    def add(self, claims: Claims | list[Claim] | Claim, action_if_exists: ActionIfExists = ActionIfExists.REPLACE_ALL) -> Claims:
         """
 
         :param claims: A Claim, list of Claim or just a Claims object to add to this Claims object.
@@ -91,10 +98,29 @@ class Claims(BaseModel):
                 elif action_if_exists == ActionIfExists.REPLACE_ALL:
                     if claim not in self.claims[property]:
                         self.claims[property].append(claim)
+                elif action_if_exists == ActionIfExists.MERGE_REFS_OR_APPEND:
+                    claim_exists = False
+                    for existing_claim in self.claims[property]:
+                        existing_claim_json = existing_claim.get_json()
+                        claim_to_add_json = claim.get_json()
 
+                        # Check if the values match, including qualifiers
+                        if (claim_to_add_json["mainsnak"]["datavalue"]["value"] == existing_claim_json["mainsnak"]["datavalue"]["value"]) and claim.quals_equal(claim, existing_claim):
+                            claim_exists = True
+
+                            # Check if current reference block is present on references
+                            if not Claim.ref_present(newitem=claim, olditem=existing_claim):
+                                for ref_to_add in claim.references:
+                                    if ref_to_add not in existing_claim.references:
+                                        existing_claim.references.add(ref_to_add)
+                            break
+
+                    # If the claim value does not exist, append it
+                    if not claim_exists:
+                        self.claims[property].append(claim)
         return self
 
-    def from_json(self, json_data: Dict[str, Any]) -> Claims:
+    def from_json(self, json_data: dict[str, Any]) -> Claims:
         for property in json_data:
             for claim in json_data[property]:
                 from wikibaseintegrator.datatypes import BaseDataType
@@ -106,8 +132,8 @@ class Claims(BaseModel):
 
         return self
 
-    def get_json(self) -> Dict[str, List]:
-        json_data: Dict[str, List] = {}
+    def get_json(self) -> dict[str, list]:
+        json_data: dict[str, list] = {}
         for property, claims in self.claims.items():
             if property not in json_data:
                 json_data[property] = []
@@ -118,20 +144,21 @@ class Claims(BaseModel):
                 del json_data[property]
         return json_data
 
-    def __len__(self):
-        return len(self.claims)
-
     def __iter__(self):
         iterate = []
         for claim in self.claims.values():
             iterate.extend(claim)
         return iter(iterate)
 
+    def __len__(self):
+        return len(self.claims)
+
 
 class Claim(BaseModel):
     DTYPE = 'claim'
 
-    def __init__(self, qualifiers: Optional[Qualifiers] = None, rank: Optional[WikibaseRank] = None, references: Optional[Union[References, List[Union[Claim, List[Claim]]]]] = None, snaktype: WikibaseSnakType = WikibaseSnakType.KNOWN_VALUE) -> None:
+    def __init__(self, qualifiers: Qualifiers | None = None, rank: WikibaseRank | None = None, references: References | list[Claim | list[Claim]] | None = None,
+                 snaktype: WikibaseSnakType = WikibaseSnakType.KNOWN_VALUE) -> None:
         """
 
         :param qualifiers:
@@ -179,11 +206,11 @@ class Claim(BaseModel):
         self.__mainsnak = value
 
     @property
-    def type(self) -> Union[str, Dict]:
+    def type(self) -> str | dict:
         return self.__type
 
     @type.setter
-    def type(self, value: Union[str, Dict]):
+    def type(self, value: str | dict):
         self.__type = value
 
     @property
@@ -196,19 +223,19 @@ class Claim(BaseModel):
         self.__qualifiers: Qualifiers = Qualifiers().set(value) if isinstance(value, list) else value
 
     @property
-    def qualifiers_order(self) -> List[str]:
+    def qualifiers_order(self) -> list[str]:
         return self.__qualifiers_order
 
     @qualifiers_order.setter
-    def qualifiers_order(self, value: List[str]):
+    def qualifiers_order(self, value: list[str]):
         self.__qualifiers_order = value
 
     @property
-    def id(self) -> Optional[str]:
+    def id(self) -> str | None:
         return self.__id
 
     @id.setter
-    def id(self, value: Optional[str]):
+    def id(self, value: str | None):
         self.__id = value
 
     @property
@@ -246,7 +273,7 @@ class Claim(BaseModel):
         self.rank = claim.rank
         self.references = claim.references
 
-    def from_json(self, json_data: Dict[str, Any]) -> Claim:
+    def from_json(self, json_data: dict[str, Any]) -> Claim:
         """
 
         :param json_data: a JSON representation of a Claim
@@ -264,8 +291,8 @@ class Claim(BaseModel):
 
         return self
 
-    def get_json(self) -> Dict[str, Any]:
-        json_data: Dict[str, Union[str, List[Dict], List[str], Dict[str, str], Dict[str, List], None]] = {
+    def get_json(self) -> dict[str, Any]:
+        json_data: dict[str, str | list[dict] | list[str] | dict[str, str] | dict[str, list] | None] = {
             'mainsnak': self.mainsnak.get_json(),
             'type': self.type,
             'id': self.id,
@@ -309,6 +336,12 @@ class Claim(BaseModel):
 
         return True
 
+    def reset_id(self):
+        """
+        Reset the ID of the current claim
+        """
+        self.id = None
+
     # TODO: rewrite this?
     def __contains__(self, item):
         if isinstance(item, Claim):
@@ -328,7 +361,7 @@ class Claim(BaseModel):
 
         raise super().__eq__(other)
 
-    def equals(self, that: Claim, include_ref: bool = False, fref: Optional[Callable] = None) -> bool:
+    def equals(self, that: Claim, include_ref: bool = False, fref: Callable | None = None) -> bool:
         """
         Tests for equality of two statements.
         If comparing references, the order of the arguments matters!!!
@@ -350,6 +383,17 @@ class Claim(BaseModel):
 
         return fref(self, that)
 
+    @staticmethod
+    def quals_equal(olditem: Claim, newitem: Claim) -> bool:
+        """
+        Tests for exactly identical qualifiers.
+        """
+
+        oldqual = olditem.qualifiers
+        newqual = newitem.qualifiers
+
+        return (len(oldqual) == len(newqual)) and all(x in oldqual for x in newqual)
+
     @staticmethod
     def refs_equal(olditem: Claim, newitem: Claim) -> bool:
         """
@@ -364,6 +408,25 @@ class Claim(BaseModel):
 
         return len(oldrefs) == len(newrefs) and all(any(ref_equal(oldref, newref) for oldref in oldrefs) for newref in newrefs)
 
+    @staticmethod
+    def ref_present(olditem: Claim, newitem: Claim) -> bool:
+        """
+        Tests if (1) there is a single ref in the new item and
+        (2) if this single ref is present among the claims of the old item.
+        """
+
+        oldrefs = olditem.references
+        newrefs = newitem.references
+
+        if len(newrefs) != 1:
+            warnings.warn("New item has more or less than 1 reference block.")
+            return False
+
+        def ref_equal(oldref: References, newref: References) -> bool:
+            return (len(oldref) == len(newref)) and all(x in oldref for x in newref)
+
+        return any(any(ref_equal(oldref, newref) for oldref in oldrefs) for newref in newrefs)
+
     @abstractmethod
     def get_sparql_value(self) -> str:
         pass
