@@ -4,9 +4,11 @@ Multiple functions or classes that can be used to interact with the Wikibase ins
 from __future__ import annotations
 
 import datetime
+import json
 import logging
+import re
 from time import sleep
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any
 from urllib.parse import urlparse
 
 import requests
@@ -15,9 +17,10 @@ from requests import Session
 
 from wikibaseintegrator.wbi_backoff import wbi_backoff
 from wikibaseintegrator.wbi_config import config
-from wikibaseintegrator.wbi_exceptions import MaxRetriesReachedException, ModificationFailed, MWApiError, NonExistentEntityError, SearchError
+from wikibaseintegrator.wbi_exceptions import MaxRetriesReachedException, ModificationFailed, MWApiError, NonExistentEntityError, SaveFailed, SearchError
 
 if TYPE_CHECKING:
+    from wikibaseintegrator.datatypes import BaseDataType
     from wikibaseintegrator.entities.baseentity import BaseEntity
     from wikibaseintegrator.wbi_login import _Login
 
@@ -45,8 +48,7 @@ class BColors:
 default_session = requests.Session()
 
 
-def mediawiki_api_call(method: str, mediawiki_api_url: Optional[str] = None, session: Optional[Session] = None, max_retries: int = 100, retry_after: int = 60,
-                       **kwargs: Any) -> Dict:
+def mediawiki_api_call(method: str, mediawiki_api_url: str | None = None, session: Session | None = None, max_retries: int = 100, retry_after: int = 60, **kwargs: Any) -> dict:
     """
     A function to call the MediaWiki API.
 
@@ -123,6 +125,12 @@ def mediawiki_api_call(method: str, mediawiki_api_url: Optional[str] = None, ses
             if 'code' in json_data['error'] and json_data['error']['code'] == 'modification-failed':  # pragma: no cover
                 raise ModificationFailed(json_data['error'])
 
+            # sitelink conflict
+            if ('code' in json_data['error'] and json_data['error']['code'] == 'failed-save' and
+                    any([message.get('name', '') == 'wikibase-validator-sitelink-conflict'
+                         for message in json_data['error'].get('messages', [])])):
+                raise SaveFailed(json_data['error'])
+
             # others case
             raise MWApiError(json_data['error'])
 
@@ -137,9 +145,8 @@ def mediawiki_api_call(method: str, mediawiki_api_url: Optional[str] = None, ses
     return json_data
 
 
-def mediawiki_api_call_helper(data: Dict[str, Any], login: Optional[_Login] = None, mediawiki_api_url: Optional[str] = None, user_agent: Optional[str] = None,
-                              allow_anonymous: bool = False,
-                              max_retries: int = 1000, retry_after: int = 60, maxlag: int = 5, is_bot: bool = False, **kwargs: Any) -> Dict:
+def mediawiki_api_call_helper(data: dict[str, Any], login: _Login | None = None, mediawiki_api_url: str | None = None, user_agent: str | None = None, allow_anonymous: bool = False,
+                              max_retries: int = 1000, retry_after: int = 60, maxlag: int = 5, is_bot: bool = False, **kwargs: Any) -> dict:
     """
     A simplified function to call the MediaWiki API.
     Pass the data, as a dictionary, related to the action you want to call, all commons options will be automatically managed.
@@ -162,7 +169,7 @@ def mediawiki_api_call_helper(data: Dict[str, Any], login: Optional[_Login] = No
     hostname = urlparse(mediawiki_api_url).hostname
     if hostname is not None and hostname.endswith(('wikidata.org', 'wikipedia.org', 'wikimedia.org')) and user_agent is None:
         log.warning('WARNING: Please set an user agent if you interact with a Wikibase instance from the Wikimedia Foundation.')
-        log.warning('More information in the README.md and https://meta.wikimedia.org/wiki/User-Agent_policy')
+        log.warning('More information in the README.md and https://foundation.wikimedia.org/wiki/Policy:User-Agent_policy')
 
     if not allow_anonymous:
         if login is None:
@@ -215,8 +222,8 @@ def mediawiki_api_call_helper(data: Dict[str, Any], login: Optional[_Login] = No
 
 
 @wbi_backoff()
-def execute_sparql_query(query: str, prefix: Optional[str] = None, endpoint: Optional[str] = None, user_agent: Optional[str] = None, max_retries: int = 1000,
-                         retry_after: int = 60) -> Dict[str, Dict]:
+def execute_sparql_query(query: str, prefix: str | None = None, endpoint: str | None = None, user_agent: str | None = None, max_retries: int = 1000, retry_after: int = 60) -> dict[
+    str, dict]:
     """
     Static method which can be used to execute any SPARQL query
 
@@ -235,7 +242,7 @@ def execute_sparql_query(query: str, prefix: Optional[str] = None, endpoint: Opt
     hostname = urlparse(sparql_endpoint_url).hostname
     if hostname is not None and hostname.endswith(('wikidata.org', 'wikipedia.org', 'wikimedia.org')) and user_agent is None:
         log.warning('WARNING: Please set an user agent if you interact with a Wikibase instance from the Wikimedia Foundation.')
-        log.warning('More information in the README.md and https://meta.wikimedia.org/wiki/User-Agent_policy')
+        log.warning('More information in the README.md and https://foundation.wikimedia.org/wiki/Policy:User-Agent_policy')
 
     if prefix:
         query = prefix + '\n' + query
@@ -278,8 +285,8 @@ def execute_sparql_query(query: str, prefix: Optional[str] = None, endpoint: Opt
     raise Exception(f"No result after {max_retries} retries.")
 
 
-def edit_entity(data: Dict, id: Optional[str] = None, type: Optional[str] = None, baserevid: Optional[int] = None, summary: Optional[str] = None, clear: bool = False,
-                is_bot: bool = False, tags: Optional[List[str]] = None, site: Optional[str] = None, title: Optional[str] = None, **kwargs: Any) -> Dict:
+def edit_entity(data: dict, id: str | None = None, type: str | None = None, baserevid: int | None = None, summary: str | None = None, clear: bool = False, is_bot: bool = False,
+                tags: list[str] | None = None, site: str | None = None, title: str | None = None, **kwargs: Any) -> dict:
     """
     Creates a single new Wikibase entity and modifies it with serialised information.
 
@@ -332,7 +339,7 @@ def edit_entity(data: Dict, id: Optional[str] = None, type: Optional[str] = None
     return mediawiki_api_call_helper(data=params, is_bot=is_bot, **kwargs)
 
 
-def merge_items(from_id: str, to_id: str, login: Optional[_Login] = None, ignore_conflicts: Optional[List[str]] = None, is_bot: bool = False, **kwargs: Any) -> Dict:
+def merge_items(from_id: str, to_id: str, login: _Login | None = None, ignore_conflicts: list[str] | None = None, is_bot: bool = False, **kwargs: Any) -> dict:
     """
     A static method to merge two items
 
@@ -359,7 +366,7 @@ def merge_items(from_id: str, to_id: str, login: Optional[_Login] = None, ignore
     return mediawiki_api_call_helper(data=params, login=login, is_bot=is_bot, **kwargs)
 
 
-def merge_lexemes(source: str, target: str, login: Optional[_Login] = None, summary: Optional[str] = None, is_bot: bool = False, **kwargs: Any) -> Dict:
+def merge_lexemes(source: str, target: str, login: _Login | None = None, summary: str | None = None, is_bot: bool = False, **kwargs: Any) -> dict:
     """
     A static method to merge two lexemes
 
@@ -386,7 +393,7 @@ def merge_lexemes(source: str, target: str, login: Optional[_Login] = None, summ
     return mediawiki_api_call_helper(data=params, login=login, is_bot=is_bot, **kwargs)
 
 
-def remove_claims(claim_id: str, summary: Optional[str] = None, baserevid: Optional[int] = None, is_bot: bool = False, **kwargs: Any) -> Dict:
+def remove_claims(claim_id: str, summary: str | None = None, baserevid: int | None = None, is_bot: bool = False, **kwargs: Any) -> dict:
     """
     Delete a claim from an entity
 
@@ -396,7 +403,7 @@ def remove_claims(claim_id: str, summary: Optional[str] = None, baserevid: Optio
     :param is_bot: Mark this edit as bot.
     """
 
-    params: Dict[str, Union[str, int]] = {
+    params: dict[str, str | int] = {
         'action': 'wbremoveclaims',
         'claim': claim_id,
         'format': 'json'
@@ -414,58 +421,8 @@ def remove_claims(claim_id: str, summary: Optional[str] = None, baserevid: Optio
     return mediawiki_api_call_helper(data=params, is_bot=is_bot, **kwargs)
 
 
-def delete_page(title: Optional[str] = None, pageid: Optional[int] = None, reason: Optional[str] = None, deletetalk: bool = False, watchlist: str = 'preferences',
-                watchlistexpiry: Optional[str] = None, login: Optional[_Login] = None, **kwargs: Any) -> Dict:
-    """
-    Delete a page
-
-    :param title: Title of the page to delete. Cannot be used together with pageid.
-    :param pageid: Page ID of the page to delete. Cannot be used together with title.
-    :param reason: Reason for the deletion. If not set, an automatically generated reason will be used.
-    :param deletetalk: Delete the talk page, if it exists.
-    :param watchlist: Unconditionally add or remove the page from the current user's watchlist, use preferences (ignored for bot users) or do not change watch.
-                      One of the following values: nochange, preferences, unwatch, watch
-    :param watchlistexpiry: Watchlist expiry timestamp. Omit this parameter entirely to leave the current expiry unchanged.
-    :param login: A wbi_login.Login instance
-    :param kwargs:
-    :return:
-    """
-
-    if not title and not pageid:
-        raise ValueError("A title or a pageid must be specified.")
-
-    if title and pageid:
-        raise ValueError("You can't specify a title and a pageid at the same time.")
-
-    if pageid and not isinstance(pageid, int):
-        raise ValueError("pageid must be an integer.")
-
-    params: Dict[str, Any] = {
-        'action': 'delete',
-        'watchlist': watchlist,
-        'format': 'json'
-    }
-
-    if title:
-        params.update({'title': title})
-
-    if pageid:
-        params.update({'pageid': pageid})
-
-    if reason:
-        params.update({'reason': reason})
-
-    if deletetalk:
-        params.update({'deletetalk': ''})
-
-    if watchlistexpiry:
-        params.update({'watchlistexpiry': watchlistexpiry})
-
-    return mediawiki_api_call_helper(data=params, login=login, **kwargs)
-
-
-def search_entities(search_string: str, language: Optional[str] = None, strict_language: bool = False, search_type: str = 'item', max_results: int = 50, dict_result: bool = False,
-                    allow_anonymous: bool = True, **kwargs: Any) -> List[Dict[str, Any]]:
+def search_entities(search_string: str, language: str | None = None, strict_language: bool = False, search_type: str = 'item', max_results: int = 50, dict_result: bool = False,
+                    allow_anonymous: bool = True, **kwargs: Any) -> list[dict[str, Any]]:
     """
     Performs a search for entities in the Wikibase instance using labels and aliases.
     You can have more information on the parameters in the MediaWiki API help (https://www.wikidata.org/w/api.php?action=help&modules=wbsearchentities)
@@ -530,11 +487,11 @@ def search_entities(search_string: str, language: Optional[str] = None, strict_l
     return results
 
 
-def lexeme_add_form(lexeme_id, data, baserevid: Optional[int] = None, tags: Optional[List[str]] = None, is_bot: bool = False, **kwargs: Any) -> Dict:
+def lexeme_add_form(lexeme_id, data, baserevid: int | None = None, tags: list[str] | None = None, is_bot: bool = False, **kwargs: Any) -> dict:
     """
     Adds Form to Lexeme
 
-    :param lexeme_id: ID of the Lexeme
+    :param lexeme_id: ID of the Lexeme, e.g. L10
     :param data: The serialized object that is used as the data source.
     :param baserevid: Base Revision ID of the Lexeme, if edit conflict check is wanted.
     :param tags: Change tags to apply to the revision.
@@ -563,11 +520,11 @@ def lexeme_add_form(lexeme_id, data, baserevid: Optional[int] = None, tags: Opti
     return mediawiki_api_call_helper(data=params, is_bot=is_bot, **kwargs)
 
 
-def lexeme_edit_form(form_id, data, baserevid: Optional[int] = None, tags: Optional[List[str]] = None, is_bot: bool = False, **kwargs: Any) -> Dict:
+def lexeme_edit_form(form_id: str, data, baserevid: int | None = None, tags: list[str] | None = None, is_bot: bool = False, **kwargs: Any) -> dict:
     """
     Edits representations and grammatical features of a Form
 
-    :param form_id: ID of the Form, e.g. L10-F2
+    :param form_id: ID of the Form or the concept URI, e.g. L10-F2
     :param data: The serialized object that is used as the data source.
     :param baserevid: Base Revision ID of the Lexeme, if edit conflict check is wanted.
     :param tags: Change tags to apply to the revision.
@@ -577,6 +534,14 @@ def lexeme_edit_form(form_id, data, baserevid: Optional[int] = None, tags: Optio
 
     """
 
+    pattern = re.compile(r'^(?:.+\/entity\/)?(L[0-9]+-F[0-9]+)$')
+    matches = pattern.match(form_id)
+
+    if not matches:
+        raise ValueError(f"Invalid Form ID ({form_id}), format must be 'L[0-9]+-F[0-9]+'")
+
+    form_id = matches.group(1)
+
     params = {
         'action': 'wbleditformelements',
         'formId': form_id,
@@ -596,11 +561,11 @@ def lexeme_edit_form(form_id, data, baserevid: Optional[int] = None, tags: Optio
     return mediawiki_api_call_helper(data=params, is_bot=is_bot, **kwargs)
 
 
-def lexeme_remove_form(form_id, baserevid: Optional[int] = None, tags: Optional[List[str]] = None, is_bot: bool = False, **kwargs: Any) -> Dict:
+def lexeme_remove_form(form_id: str, baserevid: int | None = None, tags: list[str] | None = None, is_bot: bool = False, **kwargs: Any) -> dict:
     """
     Removes Form from Lexeme
 
-    :param form_id: ID of the Form, e.g. L10-F2
+    :param form_id: ID of the Form or the concept URI, e.g. L10-F2
     :param baserevid: Base Revision ID of the Lexeme, if edit conflict check is wanted.
     :param tags: Change tags to apply to the revision.
     :param is_bot: Mark this edit as bot.
@@ -609,6 +574,14 @@ def lexeme_remove_form(form_id, baserevid: Optional[int] = None, tags: Optional[
 
     """
 
+    pattern = re.compile(r'^(?:.+\/entity\/)?(L[0-9]+-F[0-9]+)$')
+    matches = pattern.match(form_id)
+
+    if not matches:
+        raise ValueError(f"Invalid Form ID ({form_id}), format must be 'L[0-9]+-F[0-9]+'")
+
+    form_id = matches.group(1)
+
     params = {
         'action': 'wblremoveform',
         'id': form_id,
@@ -627,12 +600,12 @@ def lexeme_remove_form(form_id, baserevid: Optional[int] = None, tags: Optional[
     return mediawiki_api_call_helper(data=params, is_bot=is_bot, **kwargs)
 
 
-def lexeme_add_sense(lexeme_id, data, baserevid: Optional[int] = None, tags: Optional[List[str]] = None, is_bot: bool = False, **kwargs: Any) -> Dict:
+def lexeme_add_sense(lexeme_id, data, baserevid: int | None = None, tags: list[str] | None = None, is_bot: bool = False, **kwargs: Any) -> dict:
     """
     Adds a Sense to a Lexeme
 
-    :param lexeme_id: ID of the Lexeme
-    :param data: The serialized object that is used as the data source.
+    :param lexeme_id: ID of the Lexeme, e.g. L10
+    :param data: JSON-encoded data for the Sense, i.e. its glosses
     :param baserevid: Base Revision ID of the Lexeme, if edit conflict check is wanted.
     :param tags: Change tags to apply to the revision.
     :param is_bot: Mark this edit as bot.
@@ -660,11 +633,11 @@ def lexeme_add_sense(lexeme_id, data, baserevid: Optional[int] = None, tags: Opt
     return mediawiki_api_call_helper(data=params, is_bot=is_bot, **kwargs)
 
 
-def lexeme_edit_sense(sense_id, data, baserevid: Optional[int] = None, tags: Optional[List[str]] = None, is_bot: bool = False, **kwargs: Any) -> Dict:
+def lexeme_edit_sense(sense_id: str, data, baserevid: int | None = None, tags: list[str] | None = None, is_bot: bool = False, **kwargs: Any) -> dict:
     """
     Edits glosses of a Sense
 
-    :param sense_id: ID of the Sense, e.g. L10-S2
+    :param sense_id: ID of the Sense or the concept URI, e.g. L10-S2
     :param data: The serialized object that is used as the data source.
     :param baserevid: Base Revision ID of the Lexeme, if edit conflict check is wanted.
     :param tags: Change tags to apply to the revision.
@@ -674,6 +647,14 @@ def lexeme_edit_sense(sense_id, data, baserevid: Optional[int] = None, tags: Opt
 
     """
 
+    pattern = re.compile(r'^(?:.+\/entity\/)?(L[0-9]+-S[0-9]+)$')
+    matches = pattern.match(sense_id)
+
+    if not matches:
+        raise ValueError(f"Invalid Sense ID ({sense_id}), format must be 'L[0-9]+-S[0-9]+'")
+
+    sense_id = matches.group(1)
+
     params = {
         'action': 'wbleditsenseelements',
         'formId': sense_id,
@@ -693,11 +674,11 @@ def lexeme_edit_sense(sense_id, data, baserevid: Optional[int] = None, tags: Opt
     return mediawiki_api_call_helper(data=params, is_bot=is_bot, **kwargs)
 
 
-def lexeme_remove_sense(sense_id, baserevid: Optional[int] = None, tags: Optional[List[str]] = None, is_bot: bool = False, **kwargs: Any) -> Dict:
+def lexeme_remove_sense(sense_id: str, baserevid: int | None = None, tags: list[str] | None = None, is_bot: bool = False, **kwargs: Any) -> dict:
     """
     Adds Form to Lexeme
 
-    :param sense_id: ID of the Sense, e.g. L10-S2
+    :param sense_id: ID of the Sense, e.g. L10-S20
     :param baserevid: Base Revision ID of the Lexeme, if edit conflict check is wanted.
     :param tags: Change tags to apply to the revision.
     :param is_bot: Mark this edit as bot.
@@ -706,6 +687,14 @@ def lexeme_remove_sense(sense_id, baserevid: Optional[int] = None, tags: Optiona
 
     """
 
+    pattern = re.compile(r'^(?:.+\/entity\/)?(L[0-9]+-S[0-9]+)$')
+    matches = pattern.match(sense_id)
+
+    if not matches:
+        raise ValueError(f"Invalid Sense ID ({sense_id}), format must be 'L[0-9]+-S[0-9]+'")
+
+    sense_id = matches.group(1)
+
     params = {
         'action': 'wblremovesense',
         'id': sense_id,
@@ -724,29 +713,7 @@ def lexeme_remove_sense(sense_id, baserevid: Optional[int] = None, tags: Optiona
     return mediawiki_api_call_helper(data=params, is_bot=is_bot, **kwargs)
 
 
-def fulltext_search(search: str, max_results: int = 50, allow_anonymous: bool = True, **kwargs: Any) -> List[Dict[str, Any]]:
-    """
-    Perform a fulltext search on the mediawiki instance.
-    It's an exception to the "only wikibase related function" rule! WikibaseIntegrator is focused on wikibase-only functions to avoid spreading out and covering all functions of MediaWiki.
-
-    :param search: Search for page titles or content matching this value. You can use the search string to invoke special search features, depending on what the wiki's search backend implements.
-    :param max_results: How many total pages to return. The value must be between 1 and 500.
-    :param allow_anonymous: Allow anonymous interaction with the MediaWiki API. 'True' by default.
-    :param kwargs: Extra parameters for mediawiki_api_call_helper()
-    :return:
-    """
-    params = {
-        'action': 'query',
-        'list': 'search',
-        'srsearch': search,
-        'srlimit': max_results,
-        'format': 'json'
-    }
-
-    return mediawiki_api_call_helper(data=params, allow_anonymous=allow_anonymous, **kwargs)['query']['search']
-
-
-def generate_entity_instances(entities: Union[str, List[str]], allow_anonymous: bool = True, **kwargs: Any) -> List[Tuple[str, BaseEntity]]:
+def generate_entity_instances(entities: str | list[str], allow_anonymous: bool = True, **kwargs: Any) -> list[tuple[str, BaseEntity]]:
     """
     A method which allows for retrieval of a list of Wikidata entities. The method generates a list of tuples where the first value in the tuple is the entity's ID, whereas the
     second is the new instance of a subclass of BaseEntity containing all the data of the entity. This is most useful for mass retrieval of entities.
@@ -782,7 +749,79 @@ def generate_entity_instances(entities: Union[str, List[str]], allow_anonymous:
     return entity_instances
 
 
-def format_amount(amount: Union[int, str, float]) -> str:
+def delete_page(title: str | None = None, pageid: int | None = None, reason: str | None = None, deletetalk: bool = False, watchlist: str = 'preferences',
+                watchlistexpiry: str | None = None, login: _Login | None = None, **kwargs: Any) -> dict:
+    """
+    Delete a page
+
+    :param title: Title of the page to delete. Cannot be used together with pageid.
+    :param pageid: Page ID of the page to delete. Cannot be used together with title.
+    :param reason: Reason for the deletion. If not set, an automatically generated reason will be used.
+    :param deletetalk: Delete the talk page, if it exists.
+    :param watchlist: Unconditionally add or remove the page from the current user's watchlist, use preferences (ignored for bot users) or do not change watch.
+                      One of the following values: nochange, preferences, unwatch, watch
+    :param watchlistexpiry: Watchlist expiry timestamp. Omit this parameter entirely to leave the current expiry unchanged.
+    :param login: A wbi_login.Login instance
+    :param kwargs:
+    :return:
+    """
+
+    if not title and not pageid:
+        raise ValueError("A title or a pageid must be specified.")
+
+    if title and pageid:
+        raise ValueError("You can't specify a title and a pageid at the same time.")
+
+    if pageid and not isinstance(pageid, int):
+        raise ValueError("pageid must be an integer.")
+
+    params: dict[str, Any] = {
+        'action': 'delete',
+        'watchlist': watchlist,
+        'format': 'json'
+    }
+
+    if title:
+        params.update({'title': title})
+
+    if pageid:
+        params.update({'pageid': pageid})
+
+    if reason:
+        params.update({'reason': reason})
+
+    if deletetalk:
+        params.update({'deletetalk': ''})
+
+    if watchlistexpiry:
+        params.update({'watchlistexpiry': watchlistexpiry})
+
+    return mediawiki_api_call_helper(data=params, login=login, **kwargs)
+
+
+def fulltext_search(search: str, max_results: int = 50, allow_anonymous: bool = True, **kwargs: Any) -> list[dict[str, Any]]:
+    """
+    Perform a fulltext search on the mediawiki instance.
+    It's an exception to the "only wikibase related function" rule! WikibaseIntegrator is focused on wikibase-only functions to avoid spreading out and covering all functions of MediaWiki.
+
+    :param search: Search for page titles or content matching this value. You can use the search string to invoke special search features, depending on what the wiki's search backend implements.
+    :param max_results: How many total pages to return. The value must be between 1 and 500.
+    :param allow_anonymous: Allow anonymous interaction with the MediaWiki API. 'True' by default.
+    :param kwargs: Extra parameters for mediawiki_api_call_helper()
+    :return:
+    """
+    params = {
+        'action': 'query',
+        'list': 'search',
+        'srsearch': search,
+        'srlimit': max_results,
+        'format': 'json'
+    }
+
+    return mediawiki_api_call_helper(data=params, allow_anonymous=allow_anonymous, **kwargs)['query']['search']
+
+
+def format_amount(amount: int | str | float) -> str:
     """
     A formatting function mostly used for Quantity datatype.
     :param amount: A int, float or str you want to pass to Quantity value.
@@ -800,7 +839,7 @@ def format_amount(amount: Union[int, str, float]) -> str:
     return str(amount)
 
 
-def get_user_agent(user_agent: Optional[str]) -> str:
+def get_user_agent(user_agent: str | None = None) -> str:
     """
     Return a user agent string suitable for interacting with the Wikibase instance.
 
@@ -817,6 +856,178 @@ def get_user_agent(user_agent: Optional[str]) -> str:
 
     return return_user_agent
 
+
+properties_dt: dict = {}
+
+
+def format2wbi(entitytype: str, json_raw: str, allow_anonymous: bool = True, wikibase_url: str | None = None, **kwargs) -> BaseEntity:
+    wikibase_url = str(wikibase_url or config['WIKIBASE_URL'])
+    json_decoded = json.loads(json_raw)
+    # pprint(json_decoded)
+
+    from wikibaseintegrator.entities.baseentity import BaseEntity
+
+    entity_list = [x for x in BaseEntity.subclasses if x.ETYPE == entitytype]
+    if not entity_list:
+        raise ValueError(f'Unknown entity type: {entitytype}')
+
+    entity = entity_list[0]()
+
+    # Add aliases (for Item and MediaInfo)
+    # Add lemmas (for Lexeme)
+    # Add lexical_category (for Lexeme)
+    # Add language (for Lexeme)
+    # Add forms (for Lexeme)
+    # Add senses (for Lexeme)
+    # Add datatype (for Property)
+
+    if 'descriptions' in json_decoded and hasattr(entity, 'descriptions'):
+        for language in json_decoded['descriptions']:
+            entity.descriptions.set(language=language, value=json_decoded['descriptions'][language])  # type: ignore
+
+    if 'labels' in json_decoded and hasattr(entity, 'labels'):
+        for language in json_decoded['labels']:
+            entity.labels.set(language=language, value=json_decoded['labels'][language])  # type: ignore
+
+    if 'claims' in json_decoded:
+        properties = list(json_decoded['claims'].keys())
+
+        from wikibaseintegrator.models import Qualifiers, References
+        from wikibaseintegrator.wbi_enums import ActionIfExists
+
+        params = {
+            'action': 'wbgetentities',
+            'ids': '|'.join(properties),
+            'props': 'datatype',
+            'format': 'json'
+        }
+
+        reply = mediawiki_api_call_helper(data=params, allow_anonymous=allow_anonymous, **kwargs)
+
+        for p in reply['entities']:
+            properties_dt[p] = reply['entities'][p]['datatype']
+
+        for claim in json_decoded['claims']:
+            if isinstance(json_decoded['claims'][claim], list):
+                statements = json_decoded['claims'][claim]
+            else:
+                statements = [json_decoded['claims'][claim]]
+
+            for statement in statements:
+                qualifiers = Qualifiers()
+                if 'qualifiers' in statement:
+                    if isinstance(statement['qualifiers'], list):
+                        qualifiers_list = statement['qualifiers']
+                    else:
+                        qualifiers_list = [statement['qualifiers']]
+
+                    for qualifiers_raw in qualifiers_list:
+                        for qualifier in qualifiers_raw:
+                            qualifiers.add(_json2datatype(qualifier, qualifiers_raw[qualifier], wikibase_url))
+
+                references = References()
+                if 'references' in statement:
+                    if isinstance(statement['references'], list):
+                        references_list = statement['references']
+                    else:
+                        references_list = [statement['references']]
+
+                    for references_raw in references_list:
+                        for reference in references_raw:
+                            references.add(_json2datatype(reference, references_raw[reference], wikibase_url))
+                # TODO: Add support for references
+                sub_entity = _json2datatype(claim, statement, wikibase_url)
+                sub_entity.qualifiers.set(qualifiers)
+                # entity.references.set(references)
+                entity.claims.add(sub_entity, action_if_exists=ActionIfExists.APPEND_OR_REPLACE)
+
+    return entity
+
+
+def _json2datatype(prop_nr: str, statement: dict, wikibase_url: str | None = None, allow_anonymous=True, **kwargs) -> BaseDataType:
+    from wikibaseintegrator.datatypes.basedatatype import BaseDataType
+    wikibase_url = str(wikibase_url or config['WIKIBASE_URL'])
+
+    if prop_nr not in properties_dt:
+        params = {
+            'action': 'wbgetentities',
+            'ids': prop_nr,
+            'props': 'datatype',
+            'format': 'json'
+        }
+
+        reply = mediawiki_api_call_helper(data=params, allow_anonymous=allow_anonymous, **kwargs)
+
+        for p in reply['entities']:
+            properties_dt[p] = reply['entities'][p]['datatype']
+
+    datatype = properties_dt[prop_nr]
+
+    f = [x for x in BaseDataType.subclasses if x.DTYPE == datatype][0]
+    if f.__name__ in ['CommonsMedia', 'ExternalID', 'Form', 'GeoShape', 'Item', 'Lexeme', 'Math', 'MusicalNotation', 'Property', 'Sense', 'String', 'TabularData', 'URL']:
+        if isinstance(statement, dict):
+            value = statement['value']
+        else:
+            value = statement
+        return f(prop_nr=prop_nr, value=value)
+    elif f.__name__ == 'GlobeCoordinate':
+        altitude = statement['altitude'] or None
+        precision = statement['precision'] or None
+        globe = statement['globe'] or None
+        return f(prop_nr=prop_nr, latitude=statement['latitude'], longitude=statement['longitude'], altitude=altitude, precision=precision, globe=globe, wikibase_url=wikibase_url)
+    elif f.__name__ == 'MonolingualText':
+        return f(prop_nr=prop_nr, language=statement['language'], text=statement['text'])
+    elif f.__name__ == 'Quantity':
+        upper_bound = statement['upper_bound'] or None
+        lower_bound = statement['lower_bound'] or None
+        unit = statement['unit'] or '1'
+        return f(prop_nr=prop_nr, quantity=statement['quantity'], upper_bound=upper_bound, lower_bound=lower_bound, unit=unit, wikibase_url=wikibase_url)
+    elif f.__name__ == 'Time':
+        before = statement['before'] or 0
+        after = statement['after'] or 0
+        precision = statement['precision'] or None
+        timezone = statement['timezone'] or 0
+        calendarmodel = statement['calendarmodel'] or None
+        return f(prop_nr=prop_nr, time=statement['time'], before=before, after=after, precision=precision, timezone=timezone, calendarmodel=calendarmodel,
+                 wikibase_url=wikibase_url)
+
+    return f()
+
+
+def download_entity_ttl(entity: str, wikibase_url: str | None = None, user_agent: str | None = None) -> str:
+    """
+    Downloads the TTL (Terse RDF Triple Language) content of a specific entity from a Wikibase instance.
+
+    Args:
+    - entity (str): The identifier of the entity to download the TTL content for.
+    - wikibase_url (str | None): The base URL of the Wikibase instance. If None, the default URL from the configuration
+                                  will be used.
+    - user_agent (str | None): The user agent string to be used in the HTTP request headers. If None, the default user
+                                agent from the configuration will be used if available.
+
+    Returns:
+    - str: The TTL content of the requested entity.
+
+    Raises:
+    - HTTPError: If the HTTP request to retrieve the TTL content fails (status code other than 2xx).
+
+    Note:
+    The function relies on a configuration setup (presumably a 'config' dictionary) containing at least the keys
+    'WIKIBASE_URL' and 'USER_AGENT' for the default Wikibase URL and user agent respectively.
+    """
+    wikibase_url = str(wikibase_url or config['WIKIBASE_URL'])
+    user_agent = user_agent or (str(config['USER_AGENT']) if config['USER_AGENT'] is not None else None)
+
+    headers = {
+        'User-Agent': get_user_agent(user_agent)
+    }
+
+    response = helpers_session.get(wikibase_url + '/entity/' + entity + '.ttl', headers=headers)
+    response.raise_for_status()
+    results = response.text
+
+    return results
+
 # def __deepcopy__(memo):
 #     # Don't return a copy of the module
 #     # Deepcopy don't allow copy of modules (https://bugs.python.org/issue43093)
